# JoBase
**Fast Python Game Library**

JoBase is a blazingly fast Python game library for beginner coders.
It is written in pure C and uses the OpenGL library.

Please visit [jobase.org](https://jobase.org) for tutorials and documentation.
If you find any problems or have any questions, please contact us at [hello@jobase.org](mailto:hello@jobase.org).
